@@ -1,6 +1,7 @@
 from copy import copy
 from datetime import date
 from decimal import Decimal, getcontext as get_decimal_context
+from time import time
 
 from dateutil.relativedelta import relativedelta
 
@@ -59,8 +60,6 @@ class CheddarProduct(object):
                         cc_state=None, cc_zip=None, return_url=None, \
                         cancel_url=None, charges=None, items=None):
 
-        print cc_last_name
-                        
         data = self.build_customer_post_data(code, first_name, last_name, \
                     email, plan_code, company, is_vat_excempt, vat_number, \
                     notes, first_contact_datetime, referer, campaign_term, \
@@ -103,8 +102,7 @@ class CheddarProduct(object):
                 cc_country=None, cc_address=None, cc_city=None, \
                 cc_state=None, cc_zip=None, return_url=None, cancel_url=None, \
                 bill_date=None):
-        
-        print "Last Name:  %s" % cc_last_name
+
         data = {}
         
         if code:
@@ -249,7 +247,7 @@ class CheddarProduct(object):
         DO NOT RUN THIS UNLESS YOU REALLY, REALLY, REALLY MEAN TO!
         '''
         response = self.client.make_request(
-            path='customers/delete-all/confirm/1',
+            path='customers/delete-all/confirm/%d' % int(time()),
             method='POST'
         )
         
@@ -425,9 +423,10 @@ class Customer(object):
                 meta_data=None, method=None, \
                 cc_number=None, cc_expiration=None, \
                 cc_card_code=None, cc_first_name=None, \
-                cc_last_name=None, cc_company=None, \
+                cc_last_name=None, cc_company=None, cc_email=None,\
                 cc_country=None, cc_address=None, cc_city=None, \
-                cc_state=None, cc_zip=None, plan_code=None, bill_date=None ):
+                cc_state=None, cc_zip=None, plan_code=None, bill_date=None,
+                return_url=None, cancel_url=None,):
         
         data = self.product.build_customer_post_data( first_name=first_name,
                         last_name=last_name, email=email, plan_code=plan_code,
@@ -443,9 +442,10 @@ class Customer(object):
                         cc_card_code=cc_card_code,
                         cc_first_name=cc_first_name,
                         cc_last_name=cc_last_name, cc_company=cc_company,
-                        cc_country=cc_country, cc_address=cc_address,
-                        cc_city=cc_city, cc_state=cc_state, cc_zip=cc_zip,
-                        bill_date=bill_date,)
+                        cc_email=cc_email, cc_country=cc_country,
+                        cc_address=cc_address, cc_city=cc_city,
+                        cc_state=cc_state, cc_zip=cc_zip, bill_date=bill_date,
+                        return_url=return_url, cancel_url=cancel_url,)
         
         path = 'customers/edit'
         params = {'code': self.code}
@@ -559,7 +559,7 @@ class Subscription(object):
                         invoices=invoices, items=items, 
                         gateway_account=gateway_account, 
                         cancel_reason=cancel_reason, cancel_type=cancel_type,
-                        redirect_url=None)
+                        redirect_url=redirect_url)
         
         super(Subscription, self).__init__()
         
