@@ -249,6 +249,18 @@ class ProductTests(unittest.TestCase):
         data = copy(self.paypal_defaults)
         self.get_customer(**data)
 
+    @clear_users
+    def test_update_paypal_customer(self):
+        data = copy(self.paypal_defaults)
+        customer = self.get_customer(**data)
+        customer.update(
+            method='paypal',
+            return_url='http://example.com/update-success/',
+            cancel_url='http://example.com/update-cancel/',
+        )
+        print customer.subscription.redirect_url
+        assert False
+
         
     @clear_users
     def test_customer_repr(self):
